
# Slot: relation




URI: [biolink:variant_to_disease_association_relation](https://w3id.org/biolink/vocab/variant_to_disease_association_relation)

## Domain and Range

[VariantToDiseaseAssociation](VariantToDiseaseAssociation.md) ->  <sub>REQ</sub> [Uriorcurie](Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [VariantToDiseaseAssociation](VariantToDiseaseAssociation.md)
